@@ -116,6 +116,7 @@ int     startepisode;
 int     startmap;
 boolean autostart;
 FILE    *debugfile;
+int ffmap;
 
 boolean advancedemo;
 
@@ -142,44 +143,30 @@ const char *const standard_iwads[]=
 };
 static const int nstandard_iwads = sizeof standard_iwads/sizeof*standard_iwads;
 
-void D_ProcessEvents (void);
 void D_DoAdvanceDemo (void);
 
-//
-// EVENT HANDLING
-//
-// Events are asynchronous inputs generally generated by the game user.
-// Events can be discarded if no responder claims them
-//
+/*
+ * D_PostEvent - Event handling
+ *
+ * Called by I/O functions when an event is received.
+ * Try event handlers for each code area in turn.
+ * cph - in the true spirit of the Boom source, let the 
+ *  short ciruit operator madness begin!
+ */
 
-event_t events[MAXEVENTS];
-int eventhead, eventtail;
-
-//
-// D_PostEvent
-// Called by the I/O functions when input is detected
-//
 void D_PostEvent(event_t *ev)
 {
   /* cph - suppress all input events at game start
    * FIXME: This is a lousy kludge */
   if (gametic < 3) return;
-  events[eventhead++] = *ev;
-  eventhead &= MAXEVENTS-1;
-}
-
-//
-// D_ProcessEvents
-// Send all the events of the given timestamp down the responder chain
-//
-
-void D_ProcessEvents (void)
-{
-  // IF STORE DEMO, DO NOT ACCEPT INPUT
-  if (gamemode != commercial || W_CheckNumForName("map01") >= 0)
-    for (; eventtail != eventhead; eventtail = (eventtail+1) & (MAXEVENTS-1))
-      if (!M_Responder(events+eventtail))
-        G_Responder(events+eventtail);
+  M_Responder(ev) ||
+	  (gamestate == GS_LEVEL && (
+				     HU_Responder(ev) ||
+				     ST_Responder(ev) ||
+				     AM_Responder(ev)
+				     )
+	  ) ||
+	G_Responder(ev);
 }
 
 //
@@ -377,20 +364,17 @@ static void D_DoomLoop(void)
 {
   basetic = gametic;
 
-#ifdef HAVE_NET
-  atexit(D_QuitNetGame);       // killough
-#endif
-
   for (;;)
     {
       // frame syncronous IO operations
       I_StartFrame ();
 
+      if (ffmap == gamemap) ffmap = 0;
+
       // process one or more tics
       if (singletics)
         {
           I_StartTic ();
-          D_ProcessEvents ();
           G_BuildTiccmd (&netcmds[consoleplayer][maketic%BACKUPTICS]);
           if (advancedemo)
             D_DoAdvanceDemo ();
@@ -403,7 +387,8 @@ static void D_DoomLoop(void)
         TryRunTics (); // will run at least one tic
 
       // killough 3/16/98: change consoleplayer to displayplayer
-      S_UpdateSounds(players[displayplayer].mo);// move positional sounds
+      if (players[displayplayer].mo) // cph 2002/08/10
+	S_UpdateSounds(players[displayplayer].mo);// move positional sounds
 
       // Update display, next frame, with current state.
       D_Display();
@@ -925,13 +910,10 @@ void FindResponseFile (void)
   for (i = 1;i < myargc;i++)
     if (myargv[i][0] == '@')
       {
-        FILE *handle;
         int  size;
-        int  k;
         int  index;
-        int  indexinfile;
-        char *infile;
-        char *file;
+	int indexinfile;
+        char *file = NULL;
         const char **moreargs = malloc(myargc * sizeof(const char*));
         const char **newargv;
         // proff 04/05/2000: Added for searching responsefile
@@ -941,17 +923,17 @@ void FindResponseFile (void)
         AddDefaultExtension(fname,".rsp");
 
         // READ THE RESPONSE FILE INTO MEMORY
-        //handle = fopen (&myargv[i][1],"rb");
         // proff 04/05/2000: changed for searching responsefile
-        handle = fopen (fname,"rb");
+        // cph 2002/08/09 - use M_ReadFile for simplicity
+	size = M_ReadFile(fname, &file);
         // proff 04/05/2000: Added for searching responsefile
-        if (!handle)
+        if (size < 0)
         {
           strcat(strcpy(fname,I_DoomExeDir()),&myargv[i][1]);
           AddDefaultExtension(fname,".rsp");
-          handle = fopen (fname,"rb");
+	  size = M_ReadFile(fname, &file);
         }
-        if (!handle)
+        if (size < 0)
         {
             /* proff 04/05/2000: Changed from LO_FATAL
              * proff 04/05/2000: Simply removed the exit(1);
@@ -960,19 +942,15 @@ void FindResponseFile (void)
             I_Error("No such response file: %s",fname);
         }
         //jff 9/3/98 use logical output routine
-        lprintf(LO_CONFIRM,"Found response file %s!\n",&myargv[i][1]);
-        fseek(handle,0,SEEK_END);
-        size = ftell(handle);
+        lprintf(LO_CONFIRM,"Found response file %s\n",fname);
         // proff 04/05/2000: Added check for empty rsp file
         if (size<=0)
         {
+	  int k;
           lprintf(LO_ERROR,"\nResponse file empty!\n");
-          fclose(handle);
-          {
-            const char *firstargv = myargv[0];
-            newargv = calloc(sizeof(char *),MAXARGVS);
-            newargv[0] = firstargv;
-          }
+
+	  newargv = calloc(sizeof(char *),MAXARGVS);
+	  newargv[0] = myargv[0];
           for (k = 1,index = 1;k < myargc;k++)
           {
             if (i!=k)
@@ -981,46 +959,58 @@ void FindResponseFile (void)
           myargc = index; myargv = newargv;
           return;
         }
-        fseek(handle,0,SEEK_SET);
-        file = malloc (size);
-        fread(file,size,1,handle);
-        fclose(handle);
 
         // KEEP ALL CMDLINE ARGS FOLLOWING @RESPONSEFILE ARG
-        for (index = 0,k = i+1; k < myargc; k++)
-          moreargs[index++] = myargv[k];
+	memcpy((void *)moreargs,&myargv[i+1],(index = myargc - i - 1) * sizeof(myargv[0]));
+
+	{
+	  const char *firstargv = myargv[0];
+	  newargv = calloc(sizeof(char *),MAXARGVS);
+	  newargv[0] = firstargv;
+	}
 
         {
-          const char *firstargv = myargv[0];
-          newargv = calloc(sizeof(char *),MAXARGVS);
-          newargv[0] = firstargv;
-        }
+	  char *infile = file;
+	  indexinfile = 0;
+	  indexinfile++;  // SKIP PAST ARGV[0] (KEEP IT)
+	  do {
+	    while (size > 0 && isspace(*infile)) { infile++; size--; }
+	    if (size > 0) {
+	      char *s = malloc(size+1);
+	      char *p = s;
+	      int quoted = 0; 
 
-        infile = file;
-        indexinfile = k = 0;
-        indexinfile++;  // SKIP PAST ARGV[0] (KEEP IT)
-        do
-          {
-            newargv[indexinfile++] = infile+k;
-            while(k < size && ((*(infile+k)>= ' '+1) && (*(infile+k)<='z')))
-              k++;
-            *(infile+k) = 0;
-            while(k < size && ((*(infile+k)<= ' ') || (*(infile+k)>'z')))
-              k++;
-          }
-        while(k < size);
+	      while (size > 0) {
+		// Whitespace terminates the token unless quoted
+		if (!quoted && isspace(*infile)) break;
+		if (*infile == '\"') {
+		  // Quotes are removed but remembered
+		  infile++; size--; quoted ^= 1; 
+		} else {
+		  *p++ = *infile++; size--;
+		}
+	      }
+	      if (quoted) I_Error("Runaway quoted string in response file");
 
-        for (k = 0;k < index;k++)
-          newargv[indexinfile++] = moreargs[k];
+	      // Terminate string, realloc and add to argv
+	      *p = 0;
+	      newargv[indexinfile++] = realloc(s,strlen(s)+1);
+	    }
+	  } while(size > 0);
+	}
+	free(file);
 
-        myargc = indexinfile; myargv = newargv;
+	memcpy((void *)&newargv[indexinfile],moreargs,index*sizeof(moreargs[0]));
+	free((void *)moreargs);
+
+        myargc = indexinfile+index; myargv = newargv;
 
         // DISPLAY ARGS
         //jff 9/3/98 use logical output routine
         lprintf(LO_CONFIRM,"%d command-line args:\n",myargc);
-        for (k=1;k<myargc;k++)
-          //jff 9/3/98 use logical output routine
-          lprintf(LO_CONFIRM,"%s\n",myargv[k]);
+	for (index=1;index<myargc;index++)
+	  //jff 9/3/98 use logical output routine
+          lprintf(LO_CONFIRM,"%s\n",myargv[index]);
         break;
       }
 }
@@ -1519,6 +1509,10 @@ void D_DoomMainSetup(void)
       D_AddFile (file,source_lmp);
       //jff 9/3/98 use logical output routine
       lprintf(LO_CONFIRM,"Playing demo %s\n",file);
+      if ((p = M_CheckParm ("-ffmap")) && p < myargc-1) {
+        ffmap = atoi(myargv[p+1]);
+      }
+
     }
 
   // internal translucency set to config file value               // phares
