@@ -199,14 +199,22 @@ void I_Error(const char *error, ...) // killough 3/20/98: add const
 }
 
 int playerjoingame[MAXPLAYERS], playerleftgame[MAXPLAYERS];
-#define playeringame(i) ((playerjoingame[i] < INT_MAX) && (playerleftgame[i] == INT_MAX))
 UDP_CHANNEL remoteaddr[MAXPLAYERS];
+enum { pc_unused, pc_connected, pc_ready, pc_confirmedready, pc_playing, pc_quit } playerstate[MAXPLAYERS];
+int displaycounter;
+
+boolean n_players_in_state(int n, int ps) {
+	int i,j;
+	for (i=j=0;i<MAXPLAYERS;i++)
+		if (playerstate[i] == ps) j++;
+	return (j == n);
+}
 
 void BroadcastPacket(packet_header_t *packet, size_t len)
 {
   int i;
   for (i=0; i<MAXPLAYERS; i++)
-    if (playeringame(i))
+    if (playerstate[i] != pc_unused && playerstate[i] != pc_quit)
       I_SendPacketTo(packet, len, &remoteaddr[i]);
 }
 
@@ -214,7 +222,7 @@ byte def_game_options[GAME_OPTIONS_SIZE] = \
 { // cf g_game.c:G_WriteOptions()
   1, // monsters remember
   1, // friction
-  1, // weapon recoil
+  0, // weapon recoil
   1, // pushers
   0, // reserved/unused
   1, // player bobbing
@@ -223,7 +231,7 @@ byte def_game_options[GAME_OPTIONS_SIZE] = \
   0, 0, 0, 0, // 4 bytes of random number seed
   1, 0, 0, 0,
   0, 128, /* distfriend */
-  1, 1, 1, 1, 1, 1,
+  0, 1, 1, 1, 1, 0,
   /* Zeroes for all compatibility stuff */
 };
 
@@ -256,8 +264,7 @@ void doexit(void)
   packet_header_t packet;
 
   // Send "downed" packet
-  packet.type = PKT_DOWN;
-  packet.tic = 0; // Clients should not need the tic number, can't see a use for it
+  packet_set(&packet, PKT_DOWN, 0);
   BroadcastPacket(&packet, sizeof packet);
 }
 
@@ -272,6 +279,7 @@ static void I_InitSockets(Uint16 port)
 {
   I_InitNetwork();
   udp_socket = I_Socket(port);
+  if (!udp_socket) I_Error("I_InitSockets: failed to open UDP port %d\n",port);
 }
 #endif
 
@@ -309,6 +317,8 @@ void read_config_file(FILE* fp, struct setup_packet_s* sp)
   }
 }
 
+static int badplayer(int n) { return (n < 0 || n >= MAXPLAYERS); }
+
 int main(int argc, char** argv)
 {
   int localport = 5030, numplayers = 2, xtratics = 0, ticdup = 1;
@@ -403,8 +413,11 @@ int main(int argc, char** argv)
 
   { // no players initially
     int i;
-    for (i=0; i<MAXPLAYERS; i++)
-      playerjoingame[i] = INT_MAX; playerleftgame[i] = 0;
+    for (i=0; i<MAXPLAYERS; i++) {
+      playerjoingame[i] = INT_MAX;
+      playerleftgame[i] = 0;
+      playerstate[i] = pc_unused;
+    }
 
     // Print wads
     for (i=0; i<numwads; i++)
@@ -426,20 +439,19 @@ int main(int argc, char** argv)
     int remoteticto[MAXPLAYERS] = { 0, 0, 0, 0 };
     int backoffcounter[MAXPLAYERS] = { 0, 0, 0, 0 };
     int curplayers = 0;
+    int confirming = 0;
     boolean ingame = false;
     ticcmd_t netcmds[MAXPLAYERS][BACKUPTICS];
 
     while (1) {
-      {
   packet_header_t *packet = malloc(10000);
   size_t len;
 
-  I_WaitForPacket();
+  I_WaitForPacket(120*1000);
   while ((len = I_GetPacket(packet, 10000))) {
     if (verbose>2) printf("Received packet:");
     switch (packet->type) {
     case PKT_INIT:
-      printf("INIT\n");
       if (!ingame) {
         {
     int n;
@@ -448,12 +460,12 @@ int main(int argc, char** argv)
     /* Find player number and add to the game */
     n = *(short*)(packet+1);
 
-    if (playeringame(n))
-     for (n=0; n<MAXPLAYERS; n++)
-      if (playerjoingame[n] == INT_MAX) break;
+    if (badplayer(n) || playerstate[n] != pc_unused)
+     for (n=0; n<numplayers; n++)
+      if (playerstate[n] == pc_unused) break;
 
-    if (n == MAXPLAYERS) break; // Full game
-    playerjoingame[n] = 0;
+    if (n == numplayers) break; // Full game
+    playerstate[n] = pc_connected;
 #ifndef USE_SDL_NET
     remoteaddr[n] = sentfrom;
 #else
@@ -466,13 +478,12 @@ int main(int argc, char** argv)
 #ifdef USE_SDL_NET
     printf(" (channel %d)",remoteaddr[n]);
 #endif
-    putc('\n', stdout);
+    printf(" as player %d\n",n);
     {
       int i;
       size_t extrabytes = 0;
       // Send setup packet
-      packet->type = PKT_SETUP;
-      packet->tic = 0;
+      packet_set(packet, PKT_SETUP, 0);
       memcpy(sinfo, &setupinfo, sizeof setupinfo);
       sinfo->yourplayer = n;
       sinfo->numwads = numwads;
@@ -493,17 +504,12 @@ int main(int argc, char** argv)
       if (!ingame) {
         int from = *(byte*)(packet+1);
 
-        if (playerleftgame[from] == INT_MAX) break;
-        playerleftgame[from] = INT_MAX;
-        if (++curplayers == numplayers) {
-    ingame=true;
-    printf("All players joined, beginning game.\n");
-    packet->type = PKT_GO; packet->tic = 0;
-    BroadcastPacket(packet, sizeof *packet);
-    I_uSleep(10000);
-    BroadcastPacket(packet, sizeof *packet);
-    I_uSleep(100000);
-        }
+	if (badplayer(from) || playerstate[from] == pc_unused) break;
+	if (confirming) {
+		if (playerstate[from] != pc_confirmedready) curplayers++;
+		playerstate[from] = pc_confirmedready;
+	} else
+		playerstate[from] = pc_ready;
       }
       break;
     case PKT_TICC:
@@ -511,12 +517,13 @@ int main(int argc, char** argv)
         byte tics = *(byte*)(packet+1);
         int from = *(((byte*)(packet+1))+1);
 
+	if (badplayer(from)) break;
+
         if (verbose>2)
-            printf("tics %d - %d from %d\n", ptic(packet), ptic(packet) + tics - 1, from);
+            printf("tics %ld - %ld from %d\n", ptic(packet), ptic(packet) + tics - 1, from);
         if (ptic(packet) > remoteticfrom[from]) {
             // Missed tics, so request a resend
-            packet->tic = doom_htonl(remoteticfrom[from]);
-            packet->type = PKT_RETRANS;
+            packet_set(packet, PKT_RETRANS, remoteticfrom[from]);
             I_SendPacketTo(packet, sizeof *packet, remoteaddr+from);
         } else {
             ticcmd_t *newtic = (void*)(((byte*)(packet+1))+2);
@@ -530,6 +537,8 @@ int main(int argc, char** argv)
     case PKT_RETRANS:
       {
         int from = *(byte*)(packet+1);
+	if (badplayer(from)) break;
+
         if (verbose>2) printf("%d requests resend from %d\n", from, ptic(packet));
         remoteticto[from] = ptic(packet);
       }
@@ -537,11 +546,19 @@ int main(int argc, char** argv)
     case PKT_QUIT:
       {
         int from = *(byte*)(packet+1);
+	if (badplayer(from)) break;
 
-        if (verbose>2) printf("%d quits at %d\n", from, ptic(packet));
+	if (!ingame && playerstate[from] != pc_unused) {
+	  // If we already got a PKT_GO, we have to remove this player frmo the count of ready players. And we then flag this player slot as vacant.
+	  printf("player %d pulls out\n", from);
+	  if (playerstate[from] == pc_confirmedready) curplayers--;
+	  playerstate[from] = pc_unused;
+	} else
         if (playerleftgame[from] == INT_MAX) { // In the game
-    playerleftgame[from] = ptic(packet);
-    if (ingame && !--curplayers) exit(0); // All players have exited
+	  playerleftgame[from] = ptic(packet);
+	  --curplayers;
+	  if (verbose) printf("%d quits at %d (%d left)\n", from, ptic(packet),curplayers);
+	  if (ingame && !curplayers) exit(0); // All players have exited
         }
       }
       // Fall through and broadcast it
@@ -559,6 +576,8 @@ int main(int argc, char** argv)
         size_t size = sizeof(packet_header_t);
         packet_header_t *reply;
 
+	if (badplayer(from) || playerstate[from] != pc_unused) break;
+
         if (verbose) printf("Request for %s ", name);
         for (i=0; i<numwads; i++)
     if (!strcasecmp(name, wadname[i]))
@@ -571,7 +590,7 @@ int main(int argc, char** argv)
         } else {
     size += strlen(wadname[i]) + strlen(wadget[i]) + 2;
     reply = malloc(size);
-    reply->type = PKT_WAD; reply->tic = 0;
+    packet_set(reply, PKT_WAD, 0);
     strcpy((char*)(reply+1), wadname[i]);
     strcpy((char*)(reply+1) + strlen(wadname[i]) + 1, wadget[i]);
     printf("sending %s\n", wadget[i]);
@@ -586,15 +605,49 @@ int main(int argc, char** argv)
     }
   }
   free(packet);
+  if (!ingame && n_players_in_state(numplayers,pc_confirmedready)) {
+    int i;
+    packet_header_t gopacket;
+    packet_header_t *packet = &gopacket;
+    ingame=true;
+    printf("All players joined, beginning game.\n");
+    for (i=0; i<MAXPLAYERS; i++) {
+      if (playerstate[i] == pc_confirmedready) {
+	      playerjoingame[i] = 0;
+	      playerleftgame[i] = INT_MAX;
+	      playerstate[i] = pc_playing;
       }
+    }
+    packet_set(packet, PKT_GO, 0);
+    BroadcastPacket(packet, sizeof *packet);
+    I_uSleep(10000);
+    BroadcastPacket(packet, sizeof *packet);
+    I_uSleep(10000);
+  }
+  if (confirming && !--confirming && !ingame) {
+    int i;
+    curplayers = 0;
+    for (i=0; i<MAXPLAYERS; i++) {
+      if (playerstate[i] == pc_ready) {
+	      playerstate[i] = pc_unused;
+	      printf("Player %d dropped, no PKT_GO received in confirmation\n", i);
+      }
+      if (playerstate[i] == pc_confirmedready) playerstate[i] = pc_ready;
+    }
+  }
+  if (!ingame && n_players_in_state(numplayers,pc_ready)) {
+	  printf("All players ready, now confirming.\n");
+	  confirming = 100;
+  }
 
-      if (ingame) { // Run some tics
+  if (ingame) { // Run some tics
   int lowtic = INT_MAX;
   int i;
   for (i=0; i<MAXPLAYERS; i++)
-    if (playeringame(i))
-      if (remoteticfrom[i]<lowtic)
+    if (playerstate[i] == pc_playing || playerstate[i] == pc_quit) {
+      if (remoteticfrom[i] < playerleftgame[i]-1 && remoteticfrom[i]<lowtic)
         lowtic = remoteticfrom[i];
+    }
 
   if (verbose>1) printf("%d new tics can be run\n", lowtic - exectics);
 
@@ -602,23 +655,23 @@ int main(int argc, char** argv)
     exectics = lowtic; // count exec'ed tics
   // Now send all tics up to lowtic
   for (i=0; i<MAXPLAYERS; i++)
-    if (playeringame(i)) {
+    if (playerstate[i] == pc_playing) {
       int tics;
       if (lowtic <= remoteticto[i]) continue;
-      remoteticto[i] -= xtratics;
+      if ((remoteticto[i] -= xtratics) < 0) remoteticto[i] = 0;
       tics = lowtic - remoteticto[i];
       {
         packet_header_t *packet = malloc(sizeof(packet_header_t) + 1 +
          tics * (1 + numplayers * (1 + sizeof(ticcmd_t))));
         byte *p = (void*)(packet+1);
-        packet->type = PKT_TICS; packet->tic = doom_htonl(remoteticto[i] - xtratics);
+        packet_set(packet, PKT_TICS, remoteticto[i]);
         *p++ = tics;
         if (verbose>1) printf("sending %d tics to %d\n", tics, i);
         while (tics--) {
     int j, playersthistic = 0;
     byte *q = p++;
     for (j=0; j<MAXPLAYERS; j++)
-      if ((playerjoingame[j] < remoteticto[i]) &&
+      if ((playerjoingame[j] <= remoteticto[i]) &&
           (playerleftgame[j] > remoteticto[i])) {
         *p++ = j;
         memcpy(p, &netcmds[j][remoteticto[i]%BACKUPTICS], sizeof(ticcmd_t));
@@ -635,16 +688,32 @@ int main(int argc, char** argv)
         if (remoteticfrom[i] == remoteticto[i]) {
 	  backoffcounter[i] = 0;
 	} else if (remoteticfrom[i] > remoteticto[i]+1) {
-	  if ((backoffcounter[i] += remoteticfrom[i] - remoteticto[i] - 1) > 100) {
+	  if ((backoffcounter[i] += remoteticfrom[i] - remoteticto[i] - 1) > 35) {
 	    packet_header_t *packet = malloc(sizeof(packet_header_t));
-	    packet->type = PKT_BACKOFF; packet->tic = doom_htonl(remoteticto[i]);
+	    packet_set(packet, PKT_BACKOFF, remoteticto[i]);
 	    I_SendPacketTo(packet,sizeof *packet,remoteaddr+i);
 	    backoffcounter[i] = 0;
-	    if (verbose) fprintf(stderr,"telling client %d to back off\n",i);
+	    if (verbose) printf("telling client %d to back off\n",i);
+	    free(packet);
 	  }
 	}
       }
     }
+  }
+      if (!((ingame ? 0xff : 0xf) & displaycounter++)) { 
+        int i;
+        fprintf(stderr,"Player states: [");
+        for (i=0;i<MAXPLAYERS;i++) {
+            switch (playerstate[i]) {
+                case pc_unused: fputc(' ',stderr); break;
+                case pc_connected: fputc('c',stderr); break;
+                case pc_ready: fputc('r',stderr); break;
+                case pc_confirmedready: fputc('g',stderr); break;
+                case pc_playing: fputc('p',stderr); break;
+                case pc_quit: fputc('x',stderr); break;
+            }
+        }
+        fprintf(stderr,"]\n");
       }
     }
   }
