@@ -212,7 +212,7 @@ extern  int displayplayer;
 // Scores, rating.
 // Statistics on a given map, for intermission.
 //
-extern  int totalkills;
+extern  int totalkills, totallive;
 extern  int totalitems;
 extern  int totalsecret;
 
@@ -291,8 +291,6 @@ extern  int             mouseSensitivity_vert;
 extern  boolean         singletics;
 
 extern  int             bodyqueslot;
-extern  int             bodyquesize;                        // phares 8/10/98
-extern  mobj_t          **bodyque;                          // phares 8/10/98
 
 // Needed to store the number of the dummy sky flat.
 // Used for rendering, as well as tracking projectiles etc.
