@@ -59,6 +59,7 @@
 #include "p_setup.h"
 #include "p_saveg.h"
 #include "p_tick.h"
+#include "p_map.h"
 #include "d_main.h"
 #include "wi_stuff.h"
 #include "hu_stuff.h"
@@ -116,7 +117,7 @@ int             displayplayer; // view being displayed
 int             gametic;
 int             levelstarttic; // gametic at level start
 int             basetic;       /* killough 9/29/98: for demo sync */
-int             totalkills, totalitems, totalsecret;    // for intermission
+int             totalkills, totallive, totalitems, totalsecret;    // for intermission
 boolean         demorecording;
 boolean         demoplayback;
 boolean         singledemo;           // quit after playing a demo from cmdline
@@ -125,6 +126,7 @@ boolean         haswolflevels = false;// jff 4/18/98 wolf levels present
 static byte     *savebuffer;          // CPhipps - static
 int             autorun = false;      // always running?          // phares
 int             totalleveltimes;      // CPhipps - total time for all completed levels
+int		longtics;
 
 //
 // controls (have defaults)
@@ -261,6 +263,22 @@ static const byte* G_ReadDemoHeader(const byte* demo_p);
 // or reads it from the demo buffer.
 // If recording a demo, write it out
 //
+static inline signed char fudgef(signed char b)
+{
+  static int c;
+  if (!b || !demo_compatibility || longtics) return b;
+  if (++c & 0x1f) return b;
+  b |= 1; if (b>2) b-=2;
+  return b;
+}
+
+static inline signed short fudgea(signed short b)
+{
+  if (!b || !demo_compatibility || !longtics) return b;
+  b |= 1; if (b>2) b-=2;
+  return b;
+}
+
 
 void G_BuildTiccmd(ticcmd_t* cmd)
 {
@@ -495,8 +513,9 @@ void G_BuildTiccmd(ticcmd_t* cmd)
   else if (side < -MAXPLMOVE)
     side = -MAXPLMOVE;
 
-  cmd->forwardmove += forward;
+  cmd->forwardmove += fudgef(forward);
   cmd->sidemove += side;
+  cmd->angleturn = fudgea(cmd->angleturn);
 
   // CPhipps - special events (game new/load/save/pause)
   if (special_event & BT_SPECIAL) {
@@ -656,12 +675,6 @@ boolean G_Responder (event_t* ev)
       return true;
     }
 
-  // killough 9/29/98: reformatted
-  if (gamestate == GS_LEVEL && (HU_Responder(ev) ||  // chat ate the event
-        ST_Responder(ev) ||  // status window ate it
-        AM_Responder(ev)))   // automap ate it
-    return true;
-
   // any other key pops up menu if in demos
   //
   // killough 8/2/98: enable automap in -timedemo demos
@@ -765,10 +778,12 @@ void G_Ticker (void)
 #endif
     G_ChangedPlayerColour(consoleplayer, mapcolor_me);
   }
+  P_MapStart();
   // do player reborns if needed
   for (i=0 ; i<MAXPLAYERS ; i++)
     if (playeringame[i] && players[i].playerstate == PST_REBORN)
       G_DoReborn (i);
+  P_MapEnd();
 
   // do things to change the game state
   while (gameaction != ga_nothing)
@@ -802,10 +817,6 @@ void G_Ticker (void)
         case ga_worlddone:
           G_DoWorldDone ();
           break;
-        case ga_screenshot:
-          M_ScreenShot ();
-          gameaction = ga_nothing;
-          break;
         case ga_nothing:
           break;
         }
@@ -1043,8 +1054,6 @@ boolean G_CheckSpot(int playernum, mapthing_t *mthing)
 {
   fixed_t     x,y;
   subsector_t *ss;
-  unsigned    an;
-  mobj_t      *mo;
   int         i;
 
   if (!players[playernum].mo)
@@ -1075,16 +1084,22 @@ boolean G_CheckSpot(int playernum, mapthing_t *mthing)
 
   // flush an old corpse if needed
   // killough 2/8/98: make corpse queue have an adjustable limit
+  // killough 8/1/98: Fix bugs causing strange crashes
+
   if (bodyquesize > 0)
     {
-//    static mobj_t **bodyque;       // phares 8/10/98: moved outside routine
-      if (!bodyque)
-        bodyque = calloc(bodyquesize,sizeof*bodyque);
-      if (bodyque[bodyqueslot])
-        P_RemoveMobj(bodyque[bodyqueslot]);
-      bodyque[bodyqueslot] = players[playernum].mo;
-      if (++bodyqueslot >= bodyquesize)
-        bodyqueslot -= bodyquesize;
+      static mobj_t **bodyque;
+      static int queuesize;
+      if (queuesize < bodyquesize)
+	{
+	  bodyque = realloc(bodyque, bodyquesize*sizeof*bodyque);
+	  memset(bodyque+queuesize, 0,
+		 (bodyquesize-queuesize)*sizeof*bodyque);
+	  queuesize = bodyquesize;
+	}
+      if (bodyqueslot >= bodyquesize)
+	P_RemoveMobj(bodyque[bodyqueslot % bodyquesize]);
+      bodyque[bodyqueslot++ % bodyquesize] = players[playernum].mo;
     }
   else
     if (!bodyquesize)
@@ -1092,13 +1107,44 @@ boolean G_CheckSpot(int playernum, mapthing_t *mthing)
 
   // spawn a teleport fog
   ss = R_PointInSubsector (x,y);
-  an = ( ANG45 * (mthing->angle/45) ) >> ANGLETOFINESHIFT;
+  { // Teleport fog at respawn point
+    fixed_t xa,ya;
+    int an;
+    mobj_t      *mo;
 
-  mo = P_SpawnMobj(x+20*finecosine[an], y+20*finesine[an],
-                   ss->sector->floorheight, MT_TFOG);
+/* BUG: an can end up negative, because mthing->angle is (signed) short.
+ * We have to emulate original Doom's behaviour, deferencing past the start
+ * of the array, into the previous array (finetangent) */
+    an = ( ANG45 * ((signed)mthing->angle/45) ) >> ANGLETOFINESHIFT;
+    switch (an) {
+    case -4096: xa = finetangent[2048];   // finecosine[-4096]
+		ya = finetangent[0];      // finesine[-4096]
+		break;
+    case -3072: xa = finetangent[3072];   // finecosine[-3072]
+		ya = finetangent[1024];   // finesine[-3072]
+		break;
+    case -2048: xa = finesine[0];   // finecosine[-2048]
+		ya = finetangent[2048];   // finesine[-2048]
+		break;
+    case -1024:	xa = finesine[1024];     // finecosine[-1024]
+		ya = finetangent[3072];  // finesine[-1024]
+		break;
+    case 1024:
+    case 2048:
+    case 3072:
+    case 4096:
+    case 0:	xa = finecosine[an];
+		ya = finesine[an];
+		break;
+    default: I_Error("G_CheckSpot: unexpected angle %d\n",an);
+    }
 
-  if (players[consoleplayer].viewz != 1)
-    S_StartSound(mo, sfx_telept);  // don't start sound on first frame
+
+    mo = P_SpawnMobj(x+20*xa, y+20*ya, ss->sector->floorheight, MT_TFOG);
+
+    if (players[consoleplayer].viewz != 1)
+      S_StartSound(mo, sfx_telept);  // don't start sound on first frame
+  }
 
   return true;
 }
@@ -1175,11 +1221,6 @@ void G_DoReborn (int playernum)
     }
 }
 
-void G_ScreenShot (void)
-{
-  gameaction = ga_screenshot;
-}
-
 // DOOM Par Times
 int pars[4][10] = {
   {0},
@@ -2105,7 +2146,12 @@ void G_ReadDemoTiccmd (ticcmd_t* cmd)
     {
       cmd->forwardmove = ((signed char)*demo_p++);
       cmd->sidemove = ((signed char)*demo_p++);
-      cmd->angleturn = ((unsigned char)*demo_p++)<<8;
+      if (!longtics) {
+        cmd->angleturn = ((unsigned char)*demo_p++)<<8;
+      } else {
+	unsigned int lowbyte = (unsigned char)*demo_p++;
+        cmd->angleturn = (((signed int)(*demo_p++))<<8) + lowbyte;
+      }
       cmd->buttons = (unsigned char)*demo_p++;
     }
 }
@@ -2113,22 +2159,22 @@ void G_ReadDemoTiccmd (ticcmd_t* cmd)
 /* Demo limits removed -- killough
  * cph - record straight to file
  */
-static inline signed char fudge(signed char b)
-{
-  b |= 1; if (b>2) b-=2;
-  return b;
-}
-
 void G_WriteDemoTiccmd (ticcmd_t* cmd)
 {
-  char buf[4];
+  char buf[5];
+  char *p = buf;
 
-  buf[0] = (cmd->forwardmove && demo_compatibility) ?
-    fudge(cmd->forwardmove) : cmd->forwardmove;
-  buf[1] = cmd->sidemove;
-  buf[2] = (cmd->angleturn+128)>>8;
-  buf[3] = cmd->buttons;
-  if (fwrite(buf, sizeof(buf), 1, demofp) != 1)
+  *p++ = cmd->forwardmove;
+  *p++ = cmd->sidemove;
+  if (!longtics) {
+    *p++ = (cmd->angleturn+128)>>8;
+  } else {
+    signed short a = cmd->angleturn;
+    *p++ = a & 0xff;
+    *p++ = (a >> 8) & 0xff;
+  }
+  *p++ = cmd->buttons;
+  if (fwrite(buf, p-buf, 1, demofp) != 1)
     I_Error("G_WriteDemoTiccmd: error writing demo");
 
   /* cph - alias demo_p to it so we can read it back */
@@ -2465,7 +2511,8 @@ void G_BeginRecording (void)
     for (; i<MIN_MAXPLAYERS; i++)
       *demo_p++ = 0;
   } else { // cph - write old v1.9 demos (might even sync)
-    *demo_p++ = 109; // v1.9 has best chance of syncing these
+    longtics = M_CheckParm("-longtics");
+    *demo_p++ = longtics ? 111 : 109; // v1.9 has best chance of syncing these
     *demo_p++ = gameskill;
     *demo_p++ = gameepisode;
     *demo_p++ = gamemap;
@@ -2515,6 +2562,8 @@ static const byte* G_ReadDemoHeader(const byte *demo_p)
   if (demover < 200)     // Autodetect old demos
     {
       compatibility_level = doom_demo_compatibility;
+      if (demover >= 111) longtics = 1;
+
       G_Compatibility();
 
       // killough 3/2/98: force these variables to be 0 in demo_compatibility
@@ -2657,6 +2706,7 @@ void G_DoPlayDemo(void)
   char basename[9];
 
   ExtractFileBase(defdemoname,basename);           // killough
+  basename[8] = 0;
   demobuffer = demo_p = W_CacheLumpNum(demolumpnum = W_GetNumForName(basename));
   /* cph - store lump number for unlocking later */
 
