@@ -1,7 +1,6 @@
 /* Emacs style mode select   -*- C++ -*-
  *-----------------------------------------------------------------------------
  *
- * $Id: gl_intern.h,v 1.13.2.3 2002/07/27 15:58:45 proff_fs Exp $
  *
  *  PrBoom a Doom port merged with LxDoom and LSDLDoom
  *  based on BOOM, a modified and improved DOOM engine
@@ -33,35 +32,6 @@
 #ifndef _GL_INTERN_H
 #define _GL_INTERN_H
 
-#ifdef _WIN32
-#define WIN32_LEAN_AND_MEAN
-#include <windows.h>
-#endif
-#ifndef CALLBACK
-#define CALLBACK
-#endif
-#include <stdio.h>
-#include <string.h>
-#include <math.h>
-#include "SDL.h"
-#include "SDL_opengl.h"
-#include "doomtype.h"
-#include "w_wad.h"
-#include "m_argv.h"
-#include "z_zone.h"
-#include "d_event.h"
-#include "v_video.h"
-#include "doomstat.h"
-#include "r_bsp.h"
-#include "r_main.h"
-#include "r_draw.h"
-#include "r_sky.h"
-#include "r_plane.h"
-#include "r_data.h"
-#include "p_maputl.h"
-#include "m_bbox.h"
-#include "lprintf.h"
-
 typedef enum
 {
   GLDT_UNREGISTERED,
@@ -114,5 +84,6 @@ void gld_InitPalettedTextures(void);
 #define min(a,b) ((a)<(b)?(a):(b))
 #endif
 
-PFNGLCOLORTABLEEXTPROC glColorTableEXT;
+PFNGLCOLORTABLEEXTPROC gld_ColorTableEXT;
+
 #endif // _GL_INTERN_H
