@@ -1,7 +1,6 @@
 /* Emacs style mode select   -*- C++ -*-
  *-----------------------------------------------------------------------------
  *
- * $Id: gl_texture.c,v 1.13.2.6 2002/07/27 15:58:45 proff_fs Exp $
  *
  *  PrBoom a Doom port merged with LxDoom and LSDLDoom
  *  based on BOOM, a modified and improved DOOM engine
@@ -30,6 +29,34 @@
  *---------------------------------------------------------------------
  */
 
+#include "z_zone.h"
+#ifdef _WIN32
+#define WIN32_LEAN_AND_MEAN
+#include <windows.h>
+#endif
+#ifndef CALLBACK
+#define CALLBACK
+#endif
+#include <stdio.h>
+#include <string.h>
+#include <math.h>
+#include <SDL.h>
+#include <SDL_opengl.h>
+#include "doomtype.h"
+#include "w_wad.h"
+#include "m_argv.h"
+#include "d_event.h"
+#include "v_video.h"
+#include "doomstat.h"
+#include "r_bsp.h"
+#include "r_main.h"
+#include "r_draw.h"
+#include "r_sky.h"
+#include "r_plane.h"
+#include "r_data.h"
+#include "p_maputl.h"
+#include "m_bbox.h"
+#include "lprintf.h"
 #include "gl_intern.h"
 #include "gl_struct.h"
 
@@ -151,7 +178,7 @@ void gld_SetTexturePalette(GLenum target)
   pal[transparent_pal_index*4+1]=0;
   pal[transparent_pal_index*4+2]=0;
   pal[transparent_pal_index*4+3]=0;
-  glColorTableEXT(target, GL_RGBA, 256, GL_RGBA, GL_UNSIGNED_BYTE, pal);
+  gld_ColorTableEXT(target, GL_RGBA, 256, GL_RGBA, GL_UNSIGNED_BYTE, pal);
   W_UnlockLumpName("PLAYPAL");
 }
 
