@@ -69,6 +69,7 @@ char szConName[] = "PrBoomConWinClass";
 char Lines[(80+2)*25+1];
 char *Last = NULL;
 boolean console_inited=FALSE;
+static boolean should_exit = 0;
 
 static CALLBACK ConWndProc(HWND hwnd, UINT iMsg, WPARAM wParam, LPARAM lParam)
 {
@@ -76,6 +77,10 @@ static CALLBACK ConWndProc(HWND hwnd, UINT iMsg, WPARAM wParam, LPARAM lParam)
   HDC dc;
 
   switch (iMsg) {
+  case WM_KEYDOWN:
+    if (wParam == VK_ESCAPE)
+      should_exit = 1;
+    break;
   case WM_CLOSE:
     return 1;
     break;
@@ -101,8 +106,9 @@ static CALLBACK ConWndProc(HWND hwnd, UINT iMsg, WPARAM wParam, LPARAM lParam)
     return 0;
     break;
   default:
-    return(DefWindowProc(hwnd,iMsg,wParam,lParam));
+    break;
   }
+  return(DefWindowProc(hwnd,iMsg,wParam,lParam));
 }
 
 static void I_PrintStr (int xp, const char *cp, int count, BOOL scroll) {
@@ -140,12 +146,17 @@ static int I_ConPrintString (const char *outline)
   while (*cp) {
     for (newcp = cp, newxp = xp;
       *newcp != '\n' && *newcp != '\0' && newxp < 80;
-       newcp++, newxp++) {
-      if (*newcp == '\x8') {
-        if (xp) xp--;
-        newxp = xp;
-        cp++;
+       newcp++) {
+      if (*newcp == '\x08') {
+        newxp--;
+        break;
       }
+      else if (*newcp == '\t') {
+        newxp = ((newxp + 8) / 8) * 8;
+        break;
+      }
+      else
+        newxp++;
     }
 
     if (*cp) {
@@ -156,6 +167,10 @@ static int I_ConPrintString (const char *outline)
         Last[x+2] = ((*poop) < 32) ? 32 : (*poop);
       }
 
+      if (*newcp == '\t')
+        for (x = xp; x < newxp; x++)
+          Last[x+2] = ' ';
+
       if (Last[1] < xp + (newcp - cp))
         Last[1] = xp + (newcp - cp);
 
@@ -175,7 +190,7 @@ static int I_ConPrintString (const char *outline)
 
       xp = newxp;
 
-      if (*newcp == '\n')
+      if ((*newcp == '\n') || (*newcp == '\x08') || (*newcp == '\t'))
         cp = newcp + 1;
       else
         cp = newcp;
@@ -190,6 +205,8 @@ void I_ConTextAttr(unsigned char a)
   int r,g,b,col;
   HDC conDC;
 
+  if (!console_inited)
+    return;
   conDC=GetDC(con_hWnd);
   r=0; g=0; b=0;
   if (a & FOREGROUND_INTENSITY) col=255;
@@ -208,6 +225,20 @@ void I_ConTextAttr(unsigned char a)
   ReleaseDC(con_hWnd,conDC);
 }
 
+void I_UpdateConsole(void)
+{
+  MSG msg;
+
+  UpdateWindow(con_hWnd);
+  while(PeekMessage(&msg, NULL, 0, 0, PM_REMOVE) > 0)
+  {
+    TranslateMessage(&msg);
+    DispatchMessage(&msg);
+  }
+  if (should_exit)
+    exit(0);
+}
+
 static void Init_Console(void)
 {
   memset(Lines,0,25*(80+2)+1);
