@@ -188,6 +188,14 @@ void T_VerticalDoor (vldoor_t* door)
           case close:          // Close types do not bounce, merely wait
             break;
 
+          case blazeRaise:
+          case genBlazeRaise:
+            door->direction = 1;
+	    if (!comp[comp_blazing]) {
+	      S_StartSound((mobj_t *)&door->sector->soundorg,sfx_bdopn);
+	      break;
+	    }
+
           default:             // other types bounce off the obstruction
             door->direction = 1;
             S_StartSound((mobj_t *)&door->sector->soundorg,sfx_doropn);
