@@ -1669,6 +1669,9 @@ void A_VileChase(mobj_t* actor)
       corpsehit->flags =
         (info->flags & ~MF_FRIEND) | (actor->flags & MF_FRIEND);
 
+		  if (!((corpsehit->flags ^ MF_COUNTKILL) & (MF_FRIEND | MF_COUNTKILL)))
+		    totallive++;
+		  
                   corpsehit->health = info->spawnhealth;
       P_SetTarget(&corpsehit->target, NULL);  // killough 11/98
 
@@ -2540,9 +2543,11 @@ void A_RandomJump(mobj_t *mo)
 
 void A_LineEffect(mobj_t *mo)
 {
-  line_t junk = *lines;
+  static line_t junk;
   player_t player;
-  player_t *oldplayer = mo->player;
+  player_t *oldplayer;
+  junk = *lines;
+  oldplayer = mo->player;
   mo->player = &player;
   player.health = 100;
   junk.special = (short)mo->state->misc1;
