@@ -797,6 +797,8 @@ mobj_t* P_SpawnMobj(fixed_t x,fixed_t y,fixed_t z,mobjtype_t type)
 
   mobj->target = mobj->tracer = mobj->lastenemy = NULL;
   P_AddThinker (&mobj->thinker);
+  if (!((mobj->flags ^ MF_COUNTKILL) & (MF_FRIEND | MF_COUNTKILL)))
+    totallive++;
   return mobj;
   }
 
@@ -1080,7 +1082,8 @@ void P_SpawnMapThing (mapthing_t* mthing)
 
   // count deathmatch start positions
 
-  if (mthing->type == 11)
+  // doom2.exe has at most 10 deathmatch starts
+  if (mthing->type == 11 && (!compatibility || deathmatch_p-deathmatchstarts < 10))
     {
     // 1/11/98 killough -- new code removes limit on deathmatch starts:
 
