@@ -1433,22 +1433,27 @@ void P_SetupLevel(int episode, int map, int playermask, skill_t skill)
 
   if (rejectlump != -1)
     W_UnlockLumpNum(rejectlump);
-  rejectmatrix = W_CacheLumpNum(rejectlump = lumpnum+ML_REJECT);
+  rejectlump = lumpnum+ML_REJECT;
+  {
+    int rjlen = W_LumpLength(rejectlump);
+    int rjreq = (numsectors*numsectors+7)/8;
+    if (rjlen < rjreq) {
+      lprintf(LO_WARN,"P_SetupLevel: REJECT too short (%d<%d) - padded\n",rjlen,rjreq);
+      rejectmatrix = W_CacheLumpNumPadded(rejectlump,rjreq,0xff);
+    } else {
+      rejectmatrix = W_CacheLumpNum(rejectlump);
+    }
+  }
   P_GroupLines();
 
   P_RemoveSlimeTrails();    // killough 10/98: remove slime trails from wad
 
+  // Note: you don't need to clear player queue slots --
+  // a much simpler fix is in g_game.c -- killough 10/98
+
   bodyqueslot = 0;
-
-// phares 8/10/98: Clear body queue so the corpses from previous games are
-// not assumed to be from this one. The mobj_t's belonging to these corpses
-// are cleared in the normal freeing of zoned memory between maps, so all
-// we have to do here is clear the pointers to them.
-
-  if (bodyque)
-    memset(bodyque, 0, bodyquesize * sizeof (*bodyque)); // CPhipps - use memset
-
   deathmatch_p = deathmatchstarts;
+  P_MapStart();
   P_LoadThings(lumpnum+ML_THINGS);
 
   // if deathmatch, randomly spawn the active players
@@ -1470,6 +1475,8 @@ void P_SetupLevel(int episode, int map, int playermask, skill_t skill)
   // set up world state
   P_SpawnSpecials();
 
+  P_MapEnd();
+
   // preload graphics
   if (precache)
     R_PrecacheLevel();
