@@ -49,8 +49,12 @@ enum packet_type_e {
 typedef struct {
   byte checksum;       // Simple checksum of the entire packet
   byte type;           /* Type of packet */
+  byte reserved[2];	/* Was random in prboom <=2.2.4, now 0 */
   unsigned tic;        // Timestamp
-} packet_header_t;
+} PACKEDATTR packet_header_t;
+
+static inline void packet_set(packet_header_t* p, enum packet_type_e t, unsigned long tic)
+{ p->tic = doom_htonl(tic); p->type = t; p->reserved[0] = 0; p->reserved[1] = 0; }
 
 #ifndef GAME_OPTIONS_SIZE
 // From g_game.h
