@@ -1,7 +1,6 @@
 /* Emacs style mode select   -*- C++ -*-
  *-----------------------------------------------------------------------------
  *
- * $Id: r_segs.c,v 1.12.2.1 2002/07/20 18:08:37 proff_fs Exp $
  *
  *  PrBoom a Doom port merged with LxDoom and LSDLDoom
  *  based on BOOM, a modified and improved DOOM engine
@@ -32,9 +31,6 @@
 //
 // 4/25/98, 5/2/98 killough: reformatted, beautified
 
-static const char
-rcsid[] = "$Id: r_segs.c,v 1.12.2.1 2002/07/20 18:08:37 proff_fs Exp $";
-
 #include "doomstat.h"
 #include "r_main.h"
 #include "r_bsp.h"
@@ -801,7 +797,16 @@ void R_StoreWallRange(const int start, const int stop)
 
   if (markfloor) {
     if (floorplane)     // killough 4/11/98: add NULL ptr checks
-      floorplane = R_CheckPlane (floorplane, rw_x, rw_stopx-1);
+      /* cph 2003/04/18  - ceilingplane and floorplane might be the same
+       * visplane (e.g. if both skies); R_CheckPlane doesn't know about
+       * modifications to the plane that might happen in parallel with the check
+       * being made, so we have to override it and split them anyway if that is
+       * a possibility, otherwise the floor marking would overwrite the ceiling
+       * marking, resulting in HOM. */
+      if (markceiling && ceilingplane == floorplane)
+	floorplane = R_DupPlane (floorplane, rw_x, rw_stopx-1);
+      else
+	floorplane = R_CheckPlane (floorplane, rw_x, rw_stopx-1);
     else
       markfloor = 0;
   }
