@@ -1,7 +1,6 @@
 /* Emacs style mode select   -*- C++ -*-
  *-----------------------------------------------------------------------------
  *
- * $Id: r_things.c,v 1.14.2.1 2002/07/20 18:08:37 proff_fs Exp $
  *
  *  PrBoom a Doom port merged with LxDoom and LSDLDoom
  *  based on BOOM, a modified and improved DOOM engine
@@ -30,9 +29,6 @@
  *
  *-----------------------------------------------------------------------------*/
 
-static const char
-rcsid[] = "$Id: r_things.c,v 1.14.2.1 2002/07/20 18:08:37 proff_fs Exp $";
-
 #include "doomstat.h"
 #include "w_wad.h"
 #include "r_main.h"
@@ -491,8 +487,10 @@ void R_ProjectSprite (mobj_t* thing)
       flip = (boolean) sprframe->flip[0];
     }
 
-  // calculate edges of the shape
-  tx -= spriteoffset[lump];
+  /* calculate edges of the shape
+   * cph 2003/08/1 - fraggle points out that this offset must be flipped if the
+   * sprite is flipped; e.g. FreeDoom imp is messed up by this. */
+  tx -= flip ? spritewidth[lump] - spriteoffset[lump] : spriteoffset[lump];
   x1 = (centerxfrac + FixedMul(tx,xscale)) >>FRACBITS;
 
     // off the right side?
