@@ -1,7 +1,6 @@
 /* Emacs style mode select   -*- C++ -*-
  *-----------------------------------------------------------------------------
  *
- * $Id: s_sound.c,v 1.4.2.3 2002/07/20 18:08:37 proff_fs Exp $
  *
  *  PrBoom a Doom port merged with LxDoom and LSDLDoom
  *  based on BOOM, a modified and improved DOOM engine
@@ -29,9 +28,6 @@
  *
  *-----------------------------------------------------------------------------*/
 
-static const char
-rcsid[] = "$Id: s_sound.c,v 1.4.2.3 2002/07/20 18:08:37 proff_fs Exp $";
-
 // killough 3/7/98: modified to allow arbitrary listeners in spy mode
 // killough 5/2/98: reindented, removed useless code, beautified
 
@@ -222,7 +218,7 @@ void S_StartSoundAtVolume(void *origin_p, int sfx_id, int volume)
   if (!snd_card || nosfxparm)
     return;
 
-  is_pickup = sfx_id & PICKUP_SOUND || sfx_id == sfx_oof; // killough 4/25/98
+  is_pickup = sfx_id & PICKUP_SOUND || sfx_id == sfx_oof || (compatibility_level >= prboom_2_compatibility && sfx_id == sfx_noway); // killough 4/25/98
   sfx_id &= ~PICKUP_SOUND;
 
   // check for bogus sound #
@@ -253,9 +249,10 @@ void S_StartSoundAtVolume(void *origin_p, int sfx_id, int volume)
   // Check to see if it is audible, modify the params
   // killough 3/7/98, 4/25/98: code rearranged slightly
 
-  if (!origin || origin == players[displayplayer].mo)
+  if (!origin || origin == players[displayplayer].mo) {
     sep = NORM_SEP;
-  else
+    volume *= 8;
+  } else
     if (!S_AdjustSoundParams(players[displayplayer].mo, origin, &volume,
                              &sep, &pitch))
       return;
@@ -280,7 +277,7 @@ void S_StartSoundAtVolume(void *origin_p, int sfx_id, int volume)
   // kill old sound
   for (cnum=0 ; cnum<numChannels ; cnum++)
     if (channels[cnum].sfxinfo && channels[cnum].origin == origin &&
-        channels[cnum].is_pickup == is_pickup)
+        (comp[comp_sound] || channels[cnum].is_pickup == is_pickup))
       {
         S_StopChannel(cnum);
         break;
@@ -609,10 +606,10 @@ int S_AdjustSoundParams(mobj_t *listener, mobj_t *source,
 
   // volume calculation
   if (approx_dist < S_CLOSE_DIST)
-    *vol = snd_SfxVolume;
+    *vol = snd_SfxVolume*8;
   else
     // distance effect
-    *vol = (snd_SfxVolume * ((S_CLIPPING_DIST-approx_dist)>>FRACBITS))
+    *vol = (snd_SfxVolume * ((S_CLIPPING_DIST-approx_dist)>>FRACBITS) * 8)
       / S_ATTENUATOR;
 
   return (*vol > 0);
