@@ -397,7 +397,7 @@ void V_Init (void)
   //  if e.g. it wants a MitSHM buffer instead
 
   for (i=0 ; i<PREALLOCED_SCREENS ; i++)
-    screens[i] = Z_Calloc(SCREENWIDTH*SCREENHEIGHT, 1, PU_STATIC, NULL);
+    screens[i] = calloc(SCREENWIDTH*SCREENHEIGHT, 1);
   for (; i<4; i++) // Clear the rest (paranoia)
     screens[i] = NULL;
 }
@@ -441,8 +441,8 @@ void V_DrawMemPatch(int x, int y, int scrn, const patch_t *patch,
       || y<0
       || y+SHORT(patch->height) > ((flags & VPT_STRETCH) ? 200 :  SCREENHEIGHT))
     // killough 1/19/98: improved error message:
-    I_Error("V_DrawMemPatch: Patch origin %d,%d exceeds LFB"
-            "Bad V_DrawMemPatch (flags=%u)", x, y, flags);
+    I_Error("V_DrawMemPatch: Patch (%d,%d)-(%d,%d) exceeds LFB"
+            "Bad V_DrawMemPatch (flags=%u)", x, y, x+SHORT(patch->width), y+SHORT(patch->height), flags);
 
   if (!(flags & VPT_STRETCH)) {
     int             col;
