@@ -447,7 +447,12 @@ void *(Z_Malloc)(size_t size, int tag, void **user
      * and start cutting into virtual memory if it has it.
      */
 
+    
+#ifdef HAVE_LIBDMALLOC
+    while (!(block = dmalloc_malloc(file,line,size + HEADER_SIZE,DMALLOC_FUNC_MALLOC,0,0))) {
+#else
     while (!(block = (malloc)(size + HEADER_SIZE))) {
+#endif
       if (!blockbytag[PU_CACHE])
         I_Error ("Z_Malloc: Failure trying to allocate %lu bytes"
 #ifdef INSTRUMENTED
@@ -544,7 +549,11 @@ void (Z_Free)(void *p
 #ifdef INSTRUMENTED
           virtual_memory -= block->size + HEADER_SIZE;
 #endif
+#ifdef HAVE_LIBDMALLOC
+          dmalloc_free(file,line,block,DMALLOC_FUNC_MALLOC);
+#else
           (free)(block);
+#endif
         }
       else
         {
